---
title: <span class="badge object-type-scalar"></span> MilliBitcoin
---
# <span class="badge object-type-scalar"></span> MilliBitcoin

Currency: Milli Bitcoin (฿)

## Definition

```python
# Currency: Milli Bitcoin (฿)
MilliBitcoin: typing.Literal["currencymBTC"] = "currencymBTC"
```
